window.Gleam.initSearch([{"doc":"fswalk","title":"fswalk","content":"# fswalk\n\nRecursively walk the filesystem starting from the provided path.\n\n[![Package Version](https://img.shields.io/hexpm/v/fswalk)](https://hex.pm/packages/fswalk)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fswalk/)\n\n```sh\ngleam add fswalk\n```\n\n```gleam\nimport fswalk\n\npub fn main() {\n  fswalk.builder()\n    |&gt; fswalk.with_path(&quot;test/fixture&quot;)\n    |&gt; fswalk.with_filter(fn(entry) {\n      !string.contains(does: entry.filename, contain: &quot;ignore&quot;)\n    })\n    |&gt; fswalk.walk\n    |&gt; iterator.map(fn(it) {\n      let assert Ok(entry) = it\n      entry.filename\n    })\n    |&gt; iterator.to_list\n    |&gt; list.sort(string.compare)\n    |&gt; should.equal([\n      &quot;test/fixture/a&quot;, &quot;test/fixture/b&quot;, &quot;test/fixture/b/c&quot;, &quot;test/fixture/b/c/d&quot;,\n    ])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fswalk&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"fswalk","title":"Entry","content":"pub type Entry {\n  Entry(filename: String, stat: Stat)\n}\n\nEntry(filename: String, stat: Stat)\n\n\nSynonyms:\nfswalk.Entry\nfswalk Entry","url":"fswalk.html#Entry"},{"doc":"fswalk","title":"EntryFilter","content":"pub type EntryFilter =\n  fn(Entry) -&gt; Bool\n\n\nSynonyms:\nfswalk.EntryFilter\nfswalk EntryFilter","url":"fswalk.html#EntryFilter"},{"doc":"fswalk","title":"Non","content":"pub opaque type Non\n Private. Pending [gleam/issues/2486](https://github.com/gleam-lang/gleam/issues/2486)\n\n\nSynonyms:\nfswalk.Non\nfswalk Non","url":"fswalk.html#Non"},{"doc":"fswalk","title":"Som","content":"pub opaque type Som\n Private. Pending [gleam/issues/2486](https://github.com/gleam-lang/gleam/issues/2486)\n\n\nSynonyms:\nfswalk.Som\nfswalk Som","url":"fswalk.html#Som"},{"doc":"fswalk","title":"Stat","content":"pub type Stat {\n  Stat(is_directory: Bool)\n}\n Weak [stat](https://www.man7.org/linux/man-pages/man2/stat.2.html) implementation.\n\nStat(is_directory: Bool)\n\n\nSynonyms:\nfswalk.Stat\nfswalk Stat","url":"fswalk.html#Stat"},{"doc":"fswalk","title":"WalkBuilder","content":"pub opaque type WalkBuilder(filter, path)\n See [builder](#builder).\n\n\nSynonyms:\nfswalk.WalkBuilder\nfswalk WalkBuilder","url":"fswalk.html#WalkBuilder"},{"doc":"fswalk","title":"builder","content":"pub fn builder() -&gt; WalkBuilder(Non, Non)\n Create a new WalkBuilder\n\nSynonyms:\nfswalk.builder\nfswalk builder","url":"fswalk.html#builder"},{"doc":"fswalk","title":"each","content":"pub fn each(it: Iterator(a), fun: fn(a) -&gt; b) -&gt; Nil\n Sugar method for consuming the walk iterator instance\nSynonyms:\nfswalk.each\nfswalk each","url":"fswalk.html#each"},{"doc":"fswalk","title":"fold","content":"pub fn fold(it: Iterator(a), init: b, fun: fn(b, a) -&gt; b) -&gt; b\n Sugar method for consuming the walk iterator instance\nSynonyms:\nfswalk.fold\nfswalk fold","url":"fswalk.html#fold"},{"doc":"fswalk","title":"map","content":"pub fn map(it: Iterator(a), fun: fn(a) -&gt; b) -&gt; Iterator(b)\n Sugar method for consuming the walk iterator instance\nSynonyms:\nfswalk.map\nfswalk map","url":"fswalk.html#map"},{"doc":"fswalk","title":"walk","content":"pub fn walk(\n  builder: WalkBuilder(a, Som),\n) -&gt; Iterator(Result(Entry, FileError))\n Walks the filesystem lazily.\n\nSynonyms:\nfswalk.walk\nfswalk walk","url":"fswalk.html#walk"},{"doc":"fswalk","title":"with_filter","content":"pub fn with_filter(\n  builder: WalkBuilder(a, b),\n  filter: fn(Entry) -&gt; Bool,\n) -&gt; WalkBuilder(Som, b)\n Create a new WalkBuilder bound to a filter function. The filter should only\n expect directories passed in the Entry instances.\n\nSynonyms:\nfswalk.with_filter\nfswalk with_filter","url":"fswalk.html#with_filter"},{"doc":"fswalk","title":"with_path","content":"pub fn with_path(\n  builder: WalkBuilder(a, b),\n  path: String,\n) -&gt; WalkBuilder(a, Som)\n Create a new WalkBuilder bound to a directory path to walk\n\nSynonyms:\nfswalk.with_path\nfswalk with_path","url":"fswalk.html#with_path"},{"doc":"fswalk","title":"fswalk","content":"","url":"fswalk.html"}]);